{ pkgs ? import <nixpkgs> {} }:
let
  mkJobset = { description, nixexprpath, gitUrls }: {
    inherit description nixexprpath;
    enabled = 1;
    hidden = false;
    nixexprinput = "hydra-config";
    checkinterval = 300;
    schedulingshares = 100;
    enableemail = true;
    emailoverride = "";
    keepnr = 16;
    inputs = {
      hydra-config = {
        type = "git";
        value = "https://gitea.c3d2.de/C3D2/hydra-config.git master 1";
        emailresponsible = false;
      };
      nixpkgs = {
        type = "git";
        value = "git://github.com/NixOS/nixpkgs.git release-19.09 1";
        emailresponsible = false;
      };
    } // (builtins.mapAttrs (_: gitUrl: {
      type = "git";
      value = gitUrl;
      emailresponsible = false;
    }) gitUrls);
  };
  jobsets = {
    # TODO: pile, host tests
    spacemsg = mkJobset {
      description = "Astro's HQ IoT stuff";
      nixexprpath = "spacemsg.nix";
      gitUrls = {
        spacemsg = "https://github.com/astro/spacemsg.git master 1";
      };
    };

    yammat = mkJobset {
      description = "Matemat by nek0";
      nixexprpath = "yammat.nix";
      gitUrls = {
        yammat = "https://github.com/nek0/yammat.git master 1";
      };
    };

    tigger = mkJobset {
      description = "XMPP MUC bot";
      nixexprpath = "tigger.nix";
      gitUrls = {
        tigger = "https://github.com/astro/tigger.git master 1";
      };
    };

    slidenado = {
      description = "CmS slide generator";
      nixexprpath = "slidenado.nix";
      gitUrls = {
        slidenado = "https://github.com/c3d2/slidenado.git master 1";
      };
    };

  };

  jobsetsJson = pkgs.writeText "jobsets.json" (builtins.toJSON jobsets );
in
{
  jobsets = pkgs.runCommand "jobsets.json" {} ''
    cp ${jobsetsJson} $out
  '';
}
